CreateUserInput

Struct CreateUserInput 

#[non_exhaustive]
pub struct CreateUserInput { pub directory_id: Option<String>, pub sam_account_name: Option<String>, pub email_address: Option<String>, pub given_name: Option<String>, pub surname: Option<String>, pub other_attributes: Option<HashMap<String, AttributeValue>>, pub client_token: Option<String>, }

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
directory_id: Option<String>

The identifier (ID) of the directory that’s associated with the user.

sam_account_name: Option<String>

The name of the user.

email_address: Option<String>

The email address of the user.

given_name: Option<String>

The first name of the user.

surname: Option<String>

The last name of the user.

other_attributes: Option<HashMap<String, AttributeValue>>

An expression that defines one or more attribute names with the data type and value of each attribute. A key is an attribute name, and the value is a list of maps. For a list of supported attributes, see Directory Service Data Attributes.

Attribute names are case insensitive.

client_token: Option<String>

A unique and case-sensitive identifier that you provide to make sure the idempotency of the request, so multiple identical calls have the same effect as one single call.

A client token is valid for 8 hours after the first request that uses it completes. After 8 hours, any request with the same client token is treated as a new request. If the request succeeds, any future uses of that token will be idempotent for another 8 hours.

If you submit a request with the same client token but change one of the other parameters within the 8-hour idempotency window, Directory Service Data returns an ConflictException.

This parameter is optional when using the CLI or SDK.

Implementations

Source

impl CreateUserInput

pub fn directory_id(&self) -> Option<&str>

The identifier (ID) of the directory that’s associated with the user.

pub fn sam_account_name(&self) -> Option<&str>

The name of the user.

pub fn email_address(&self) -> Option<&str>

The email address of the user.

pub fn given_name(&self) -> Option<&str>

The first name of the user.

pub fn surname(&self) -> Option<&str>

The last name of the user.

pub fn other_attributes(&self) -> Option<&HashMap<String, AttributeValue>>

An expression that defines one or more attribute names with the data type and value of each attribute. A key is an attribute name, and the value is a list of maps. For a list of supported attributes, see Directory Service Data Attributes.

Attribute names are case insensitive.

pub fn client_token(&self) -> Option<&str>

A unique and case-sensitive identifier that you provide to make sure the idempotency of the request, so multiple identical calls have the same effect as one single call.

A client token is valid for 8 hours after the first request that uses it completes. After 8 hours, any request with the same client token is treated as a new request. If the request succeeds, any future uses of that token will be idempotent for another 8 hours.

If you submit a request with the same client token but change one of the other parameters within the 8-hour idempotency window, Directory Service Data returns an ConflictException.

This parameter is optional when using the CLI or SDK.

Source

impl CreateUserInput

pub fn builder() -> CreateUserInputBuilder

Creates a new builder-style object to manufacture CreateUserInput.